import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Input from '../Input/index.js';
import { a as classCallCheck, b as createClass, c as inherits, d as objectWithoutProperties, e as possibleConstructorReturn, f as taggedTemplateLiteral, g as toConsumableArray, h as _extends } from '../../chunk-a9eac9e3.js';
import 'styled-components';
import '../../chunk-6a2706e0.js';
import '../../chunk-a66336c0.js';
import '../Icons/Check/index.js';
import '../Icons/Search/index.js';

/* eslint-disable */
var getFormattedValue = function getFormattedValue(e) {
  return !priceToInt(e.target.value) ? '0' : formatPriceOnKeyPress(e, true);
};

var formatPrice = function formatPrice(price) {
  if (price.toString().includes('R$')) return price;

  return price.toLocaleString('pt-BR', { style: 'currency', currency: 'BRL' });
};

var formatPriceOnKeyPress = function formatPriceOnKeyPress(e, symbol) {
  var value = e.target.value.replace('R$', '');
  var regex = /^[0-9,.\s]*$/;

  if (!value || !regex.test(value) || value === '.' || value === ',') return value.replace(/[a-z,.]/gi, '');

  var val = value.replace(/[^\d]/g, '');
  if (val.length === 1) {
    val = val.replace(/(\d{1}).*/g, '0,0$1');
  } else if (val.length < 3) {
    val = val.replace(/([0-9]{2}).*/g, '0,$1');
  } else {
    val = val.replace(/^0/g, '');
    val = val.replace(/([\d]{2})$/g, ',$1');
    val = val.replace(/(\d)(?=(\d{3})+\b)/g, '$1.');
  }

  if (symbol === true) val = 'R$ ' + val;

  return val;
};

var priceToInt = function priceToInt(price) {
  var str = void 0;

  if (typeof price === 'number') {
    str = 'R$ ' + price;
    str = str.replace('.', '');
    str = String(str);
  } else if (price === '') {
    str = 'R$ 0,00';
  } else {
    str = String(price);
  }

  var res = str.replace(/[a-zR$]/gi, '');
  res = res.replace('.', '');
  res = res.replace(',', '');
  res = parseInt(res, 10);

  return res;
};

var getTargetInputParams = function getTargetInputParams(e) {
  return {
    pos: e.target.selectionStart,
    prevValue: e.target.defaultValue,
    selectionReplacement: e.target.defaultValue.length === e.target.value.length,
    replacedAll: e.target.value.length === 4,
    backspaceClick: e.target.defaultValue.length > e.target.value.length
  };
};

var adjustCaretPosition = function adjustCaretPosition(inputParams, formattedValue) {
  var pos = inputParams.pos,
      prevValue = inputParams.prevValue,
      selectionReplacement = inputParams.selectionReplacement,
      backspaceClick = inputParams.backspaceClick,
      replacedAll = inputParams.replacedAll;

  var _formattedInputInform = formattedInputInformations(inputParams, formattedValue),
      dotAddedInValue = _formattedInputInform.dotAddedInValue,
      nextToComma = _formattedInputInform.nextToComma,
      nextToDot = _formattedInputInform.nextToDot,
      currDotPosition = _formattedInputInform.currDotPosition,
      dotRemovedFromValue = _formattedInputInform.dotRemovedFromValue,
      currCommaPosition = _formattedInputInform.currCommaPosition,
      secondNextToComma = _formattedInputInform.secondNextToComma,
      sameLength = _formattedInputInform.sameLength;

  var backspaceInLastPosition = false;
  if (prevValue.length === formattedValue.length) {
    backspaceInLastPosition = backspaceClick && pos + 1 === formattedValue.length;
  } else if (prevValue.length > formattedValue.length) {
    backspaceInLastPosition = backspaceClick && pos === formattedValue.length;
  }

  if (dotAddedInValue) {
    if (nextToComma || pos === 4) {
      return pos;
    } else {
      return pos + 1;
    }
  } else if (nextToDot) {
    if (selectionReplacement) {
      return pos;
    } else {
      return currDotPosition;
    }
  } else if (dotRemovedFromValue) {
    return pos - 1;
  } else if (nextToComma) {
    if (selectionReplacement) {
      return pos;
    } else if (backspaceInLastPosition) {
      return formattedValue.length + 1;
    } else {
      return currCommaPosition;
    }
  } else if (backspaceInLastPosition) {
    return prevValue.length;
  } else if (replacedAll) {
    return formattedValue.length;
  } else if (secondNextToComma && sameLength && !selectionReplacement) {
    return pos - 1;
  } else {
    return pos;
  }
};

var formattedInputInformations = function formattedInputInformations(inputParams, formattedValue) {
  var pos = inputParams.pos,
      prevValue = inputParams.prevValue;

  return {
    prevHasDot: prevValue.includes('.'),
    currHasDot: formattedValue.includes('.'),
    dotAddedInValue: !prevValue.includes('.') && formattedValue.includes('.'),
    dotRemovedFromValue: prevValue.includes('.') && !formattedValue.includes('.'),
    prevCommaPosition: prevValue.indexOf(','),
    currCommaPosition: formattedValue.indexOf(','),
    prevDotPosition: prevValue.indexOf('.'),
    currDotPosition: formattedValue.indexOf('.'),
    nextToComma: pos - 1 === prevValue.indexOf(',') + 1,
    nextToDot: pos - 1 === prevValue.indexOf('.') + 1,
    secondNextToComma: pos - 2 === prevValue.indexOf(',') + 1,
    sameLength: prevValue.length === formattedValue.length
  };
};

/* eslint-enable */

var InputCurrency = function (_Component) {
  inherits(InputCurrency, _Component);

  function InputCurrency() {
    var _ref;

    var _temp, _this, _ret;

    classCallCheck(this, InputCurrency);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = possibleConstructorReturn(this, (_ref = InputCurrency.__proto__ || Object.getPrototypeOf(InputCurrency)).call.apply(_ref, [this].concat(args))), _this), _this.state = { caretPosition: null, event: null }, _this.onChangePrice = function (e, onChange) {
      e.persist();
      var targetInputParams = getTargetInputParams(e);
      var hasLetters = e.target.value.replace('R$', '').match(/[a-z]/i);
      var formattedValue = getFormattedValue(e);

      if (!hasLetters) {
        _this.setState({
          event: e,
          caretPosition: adjustCaretPosition(targetInputParams, formattedValue)
        });
      }

      return onChange(e, hasLetters ? e.target.defaultValue : formattedValue);
    }, _temp), possibleConstructorReturn(_this, _ret);
  }

  createClass(InputCurrency, [{
    key: 'componentDidUpdate',
    value: function componentDidUpdate(prevProps) {
      var value = this.props;
      var _state = this.state,
          caretPosition = _state.caretPosition,
          event = _state.event;

      if (prevProps.value !== value && !!caretPosition) {
        event.target.setSelectionRange(caretPosition, caretPosition);
      }
    }
  }, {
    key: 'render',
    value: function render() {
      var _this2 = this;

      var _props = this.props,
          id = _props.id,
          name = _props.name,
          type = _props.type,
          value = _props.value,
          _onChange = _props.onChange,
          onFocus = _props.onFocus,
          placeholder = _props.placeholder,
          disabled = _props.disabled,
          error = _props.error,
          customStyles = _props.customStyles,
          checked = _props.checked,
          className = _props.className,
          width = _props.width,
          required = _props.required;

      return React.createElement(Input, {
        id: id,
        name: name,
        type: type,
        value: formatPrice(priceToInt(value) / 100),
        onChange: function onChange(e) {
          return _this2.onChangePrice(e, _onChange);
        },
        onFocus: onFocus,
        placeholder: placeholder,
        disabled: disabled,
        error: error,
        customStyles: customStyles,
        checked: checked,
        className: 'input-currency-4all ' + className,
        width: width,
        required: required
      });
    }
  }]);
  return InputCurrency;
}(Component);


InputCurrency.propTypes = {
  id: PropTypes.string,
  name: PropTypes.string,
  type: PropTypes.string,
  value: PropTypes.any,
  onChange: PropTypes.func.isRequired,
  onFocus: PropTypes.func,
  placeholder: PropTypes.string,
  disabled: PropTypes.bool,
  error: PropTypes.bool,
  customStyles: PropTypes.object,
  checked: PropTypes.bool,
  className: PropTypes.string,
  width: PropTypes.string,
  required: PropTypes.bool
};

InputCurrency.defaultProps = {
  id: '',
  name: '',
  type: 'text',
  value: '',
  onFocus: null,
  placeholder: 'R$',
  disabled: false,
  error: false,
  checked: false,
  customStyles: {},
  className: '',
  width: '100%',
  required: false
};

export default InputCurrency;
//# sourceMappingURL=index.js.map
